@@ -27,7 +27,7 @@ def _printCommands(commands, Categories, _startMessage):
   print(_startMessage)
   print(Color("Commands", "yellow", attrs=["bold"]))
   for x in range(len(commands)):
-    print(f"  [{str(x)}] - {commands[str(x)]['name']}")
+    print(f"  [{str(x + 1)}] - {commands[str(x + 1)]['name']}")
 
   if Categories != None:
     if len(Categories) > 0:
@@ -91,6 +91,7 @@ class Category():
     categories[category_name] = {'commands': {}}
 
   def AddCommand(self, command_name: str, command_function):
+    print(len(categories[self._cName]['commands']) + 1)
     """Add command into the Category"""
     categories[self._cName]['commands'][str(
       len(categories[self._cName]['commands']) + 1)] = {
@@ -100,14 +101,14 @@ class Category():
       }
 
   def _setupCategory(self):
-    for _, j in enumerate(categories):
-      print('')
-      print(Color(j, 'green', attrs=['bold']))
+    # for _, j in enumerate(categories):
+    print('')
+    print(Color(self._cName, 'green', attrs=['bold']))
 
-      for x in range(len(categories[self._cName]['commands'])):
-        print(
-          f"  [{categories[j]['commands'][str(x + 1)]['id']}] - {categories[j]['commands'][str(x + 1)]['name']}"
-        )
+    for x in range(len(categories[self._cName]['commands'])):
+      print(
+        f"  [{categories[self._cName]['commands'][str(x + 1)]['id']}] - {categories[self._cName]['commands'][str(x + 1)]['name']}"
+      )
 
 
 isCategory = False
@@ -135,14 +136,14 @@ class Command():
     self._commands = _commands
 
     for x in range(len(self._commands)):
-      if (self._commands[str(x)]['func'] == self._func):
+      if (self._commands[str(x + 1)]['func'] == self._func):
         raise Exceptions.FunctionAlreadyExists(self._func)
         return
-      elif (self._commands[str(x)]['name'] == self._name):
+      elif (self._commands[str(x + 1)]['name'] == self._name):
         raise Exceptions.CommandNameAlreadyExists(self._name)
         return
 
-    self._commands[str(len(_commands))] = {
+    self._commands[str(len(_commands) + 1)] = {
       'name': self._name,
       'func': self._func
     }
@@ -151,7 +152,6 @@ class Command():
     global categories, cc
 
     if arged:
-      print(Color("You ran an argument, script won't run normally.", 'red', attrs=['bold']))
       return 
 
     _printCommands(self._commands, Categories, self._startMessage)
